<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Treatment;
use App\Models\City;
use App\Repositories\Interfaces\Cityinterface;
use App\Traits\FileUploadTrait;
use Illuminate\Http\Request;
use Illuminate\View\View;

class CityController extends Controller
{

    use FileUploadTrait;
    private $repoCity;

    public function __construct(Cityinterface $repoCity/*,OrderInterface $repoOrder*/)
    {
        $this->repoCity = $repoCity;
    }

    public function list(Request $request)
    {
        $city = $this->repoCity->list();

        return view('Admin.City.list')
            ->with('city', $city);
    }

    public function create(Request $request)
    {

        return view('Admin.City.create');
    }

    public function store(Request $request)
    {

        $validatedData = $request->validate([

            'name_en' => 'required|string',
            'name_bn' => 'nullable|string',
            'name_ar' => 'nullable|string',
            'name_hi' => 'nullable|string',


        ]);
        $doctor = $this->repoCity->store($request);
        return redirect()->route('city.list')->with('success', 'City created successfully!');
    }

    public function edit(Request $request, $id)
    {
        $city = $this->repoCity->find($id);




        if (!$city) {
            abort(404, 'Treatment not found');
        }

        return view('Admin.City.edit')
            ->with('cityInfo', $city);
    }

    public function update(Request $request, $id)
    {
        // Validate the request data
        $validatedData = $request->validate([

            'name_en' => 'string',
            'name_bn' => 'nullable|string',
            'name_ar' => 'nullable|string',
            'name_hi' => 'nullable|string',

        ]);

        $treatment = $this->repoCity->update($id, $request);
        return redirect()->route('city.list')->with('success', 'Doctor updateted successfully!');
    }



    public function delete($id)
    {
        $deletedCity = $this->repoCity->delete($id);

        if ($deletedCity) {
            // Handle successful soft delete
            return redirect()->route('city.list')->with('success', 'City deleted successfully');
        } else {
            // Handle case where doctor is not found
            return redirect()->route('city.list')->with('error', 'City not found');
        }
    }

}
