<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Repositories\Interfaces\Treatmentinterface;
use App\Repositories\Interfaces\Countryinterface;
use App\Traits\FileUploadTrait;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\View\View;

class CountryController extends Controller
{
    use FileUploadTrait;
    private $repoCountry;

    public function __construct(Countryinterface $repoCountry/*,OrderInterface $repoOrder*/)
    {
        $this->repoCountry = $repoCountry;
    }

    public function list(Request $request)
    {
        $treatments = $this->repoCountry->list();

        return view('Admin.Country.list')
            ->with('records', $treatments);
    }

    public function listCity(Request $request, $id)
    {
        $cities = $this->repoCountry->listCity($id);

        return view('Admin.Country.city_list')
            ->with('records', $cities);
    }

    public function create(Request $request)
    {

        return view('Admin.Country.create');
    }

    public function store(Request $request)
    {
        // Validate the request data
        $validatedData = $request->validate([
            'name_en' => 'nullable|string',
            'description' => 'nullable|string',
            'flag_img' => 'image|mimes:jpeg,png,jpg,gif,webp|max:2048',
            'country_img' => 'image|mimes:jpeg,png,jpg,gif,webp|max:2048',
        ]);

        $imgName = $this->uploadFile(1, $request->flag_img);
        $imgNameIcon = $this->uploadFile(1, $request->country_img);

        $treatment = $this->repoCountry->store($request, $imgName, $imgNameIcon);
        return redirect()->route('countries.list')->with('success', 'Contry created successfully!');
    }


    public function storeCity(Request $request)
    {
        // Validate the request data
        $validatedData = $request->validate([
            'name_en' => 'nullable|string',
            'description' => 'nullable|string',
            'img' => 'image|mimes:jpeg,png,jpg,gif,webp|max:2048',
        ]);

        $imgName = $this->uploadFile(1, $request->img);

        $treatment = $this->repoCountry->storeCity($request, $imgName);
        return redirect()->route('countries.list')->with('success', 'City created successfully!');
    }

    public function edit(Request $request, $id)
    {
        $treatment = $this->repoCountry->find($id);

        if (!$treatment) {
            abort(404, 'Treatment not found');
        }

        return view('Admin.Country.edit')
            ->with('treatmentInfo', $treatment);
    }

    public function view(Request $request, $id)
    {
        $treatment = $this->repoTreatment->find($id);
        if (!$treatment) {
            abort(404, 'Treatment not found');
        }

        // Fetch treatments with the same parent_id as the current treatment's ID
        // Fetch child treatments using the repository
        $childTreatments = $this->repoTreatment->getChildTreatments($id);

        return view('Admin.Treatment.view')
            ->with('treatmentInfo', $treatment)
            ->with('childTreatments', $childTreatments);
    }

    public function update(Request $request, $id)
    {
        // Validate the request data
        $validatedData = $request->validate([
            'name_en' => 'nullable|string',
            'description' => 'nullable|string',
            'flag_img' => 'image|mimes:jpeg,png,jpg,gif,webp|max:2048',
            'country_img' => 'image|mimes:jpeg,png,jpg,gif,webp|max:2048',
        ]);

        $imgName = $this->uploadFile(1, $request->flag_img);
        $imgNameIcon = $this->uploadFile(1, $request->country_img);
        // $treatment = $this->repoTreatment->update($validatedData);

        $treatment = $this->repoCountry->update($id, $request, $imgName, $imgNameIcon);

        return redirect()->route('countries.list')->with('success', 'Country updateted successfully!');
    }

    public function updateCity(Request $request, $id)
    {
        // Validate the request data
        $validatedData = $request->validate([
            'name_en' => 'nullable|string',
            'img' => 'image|mimes:jpeg,png,jpg,gif,webp|max:2048'
        ]);

        $imgName = $this->uploadFile(1, $request->img);

        // $treatment = $this->repoTreatment->update($validatedData);

        $treatment = $this->repoCountry->updateCity($id, $request, $imgName);

        return redirect()->back()->with('success', 'City updated successfully!');
    }








    public function delete($id)
    {
        $deletedTreatment = $this->repoCountry->delete($id);

        if ($deletedTreatment) {
            // Handle successful soft delete
            return redirect()->route('countries.list')->with('success', 'Country deleted successfully');
        } else {
            // Handle case where doctor is not found
            return redirect()->route('countries.list')->with('error', 'Country not found');
        }
    }
    public function deleteCity($id)
    {
        $deletedTreatment = $this->repoCountry->deleteCity($id);

        if ($deletedTreatment) {
            // Handle successful soft delete
            return redirect()->back()->with('success', 'City Deleted Successfully');
        } else {
            // Handle case where doctor is not found

            return redirect()->back()->with('success', 'City not found successfully!');
        }
    }


}
