<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Treatment;
use App\Models\City;
use App\Repositories\Interfaces\Courseinterface;
use App\Traits\FileUploadTrait;
use Illuminate\Http\Request;
use Illuminate\View\View;
use App\Models\CourseCategory;
class CourseController extends Controller
{

    use FileUploadTrait;
    private $repoCourse;

    public function __construct(Courseinterface $repoCourse/*,OrderInterface $repoOrder*/)
    {
        $this->repoCourse = $repoCourse;
    }

    public function listCourseCat(Request $request)
    {
        $city = $this->repoCourse->listCourseCat();

        return view('Admin.Course.CatList')
            ->with('records', $city);
    }
    public function list(Request $request)
    {
        $city = $this->repoCourse->list();

        return view('Admin.Course.list')
            ->with('records', $city);
    }

    public function create(Request $request)
    {
        $city['cities']=City::where('is_delete',0)->get();
        $city['cats']=CourseCategory::where('is_delete',0)->get();

        return view('Admin.Course.create',$city);
    }
    public function storeCat(Request $request){
        $validatedData = $request->validate([
            'name_en' => 'required|string',

        ]);


        $course = $this->repoCourse->storeCat($request);
        return redirect()->back()->with('success', 'Course Category created successfully!');

    }

    public function store(Request $request)
    {
        $validatedData = $request->validate([
            'name_en' => 'required|string',
            'img' => 'image|mimes:jpeg,png,jpg,gif,webp|max:2048'

        ]);
        $imgName = $this->uploadFile(1, $request->img);

        $course = $this->repoCourse->store($request, $imgName);
        return redirect()->route('course.list')->with('success', 'Course created successfully!');
    }

    public function edit(Request $request, $id)
    {
        $course = $this->repoCourse->find($id);
        $city=City::where('is_delete',0)->get();
        $courseCat=CourseCategory::where('is_delete',0)->get();
        if (!$course) {
            abort(404, 'Treatment not found');
        }

        return view('Admin.Course.edit')
            ->with('courseInfo', $course)
            ->with('cities', $city)
            ->with('cats', $courseCat);
    }
    public function updateCat(Request $request){
           // Validate the request data
        $validatedData = $request->validate([
            'name_en' => 'nullable|string',
        ]);

        $id = $request->id;

        // Prepare update data
        $updateData = [
            'name_en' => $request->name_en,
        ];

        // Update the course
        $this->repoCourse->updateCat($id, $updateData);

        return redirect()->back()->with('success', 'Course Category Updated Successfully!');
    }

    public function update(Request $request, $id)
    {
        // Validate the request data
        $validatedData = $request->validate([
            'name_en' => 'nullable|string',
            'description' => 'nullable|string',
            'city_id' => 'nullable|integer',
            'img' => 'nullable|image|mimes:jpeg,png,jpg,gif,webp|max:2048', // Nullable for optional image upload
        ]);

        // Find the course
        $course = $this->repoCourse->find($id);
        if (!$course) {
            return redirect()->route('course.list')->with('error', 'Course not found!');
        }

        // Prepare update data
        $updateData = [
            'name_en' => $request->name_en,
            'description' => $request->description,
            'city_id' => $request->city_id,
            'course_cat_id' => $request->course_cat_id,
        ];

        // Upload and update image only if a new one is provided
        if ($request->hasFile('img')) {
            $updateData['img'] = $this->uploadFile(1, $request->file('img'));
        }

        // Update the course
        $this->repoCourse->update($id, $updateData);

        return redirect()->route('course.list')->with('success', 'Course updated successfully!');
    }






    public function delete($id)
    {
        $deletedCity = $this->repoCourse->delete($id);

        if ($deletedCity) {
            // Handle successful soft delete
            return redirect()->route('course.list')->with('success', 'Course deleted successfully');
        } else {
            // Handle case where doctor is not found
            return redirect()->route('course.list')->with('error', 'Course not found');
        }
    }
    public function deleteCat($id){
        $deletedCity = $this->repoCourse->deleteCat($id);

        if ($deletedCity) {
            // Handle successful soft delete
            return redirect()->back()->with('success', 'Course deleted successfully');
        } else {
            // Handle case where doctor is not found
            return redirect()->back()->with('error', 'Course not found');
        }
    }

}
