<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Treatment;
use App\Repositories\Interfaces\Doctorinterface;
use App\Traits\FileUploadTrait;
use Illuminate\Http\Request;
use Illuminate\View\View;

class DoctorController extends Controller
{

    use FileUploadTrait;
    private $repoDoctor;

    public function __construct(Doctorinterface $repoDoctor/*,OrderInterface $repoOrder*/)
    {
        $this->repoDoctor = $repoDoctor;
    }

    public function list(Request $request)
    {
        $doctors = $this->repoDoctor->list();

        return view('Admin.Doctor.list')
            ->with('doctors', $doctors);
    }

    public function create(Request $request)
    {
        $treatment = Treatment::where('is_delete', 0)->select('id', 'treatment_name_en')->get();
        $treatments['treatments'] = $treatment;
        return view('Admin.Doctor.create', $treatments);
    }

    public function store(Request $request)
    {

        $validatedData = $request->validate([
            'img' => 'required|image|mimes:jpeg,png,jpg,gif,webp|max:2048',
            'name_en' => 'required|string',
            'name_bn' => 'nullable|string',
            'name_ar' => 'nullable|string',
            'name_hi' => 'nullable|string',
            'experience_en' => 'nullable|string',
            'experience_ar' => 'nullable|string',
            'experience_bn' => 'nullable|string',
            'experience_hi' => 'nullable|string',
            'hospital_id' => 'nullable',
            'fb_link' => 'nullable|url',
            'insta_link' => 'nullable|url',
            'twitter_link' => 'nullable|url',
            'linkdid' => 'nullable|url',
            'specialist_en' => 'nullable|string',
            'specialist_bn' => 'nullable|string',
            'specialist_ar' => 'nullable|string',
            'specialist_hi' => 'nullable|string',
            'about_doctor_en' => 'nullable|string',
            'about_doctor_bn' => 'nullable|string',
            'about_doctor_ar' => 'nullable|string',
            'about_doctor_hi' => 'nullable|string',
            'work_exp_his_en' => 'nullable|string',
            'work_exp_his_bn' => 'nullable|string',
            'work_exp_his_ar' => 'nullable|string',
            'work_exp_his_hi' => 'nullable|string',
            'qualification_en' => 'nullable|string',
            'qualification_bn' => 'nullable|string',
            'qualification_ar' => 'nullable|string',
            'qualification_hi' => 'nullable|string',
            'awards_en' => 'nullable|string',
            'awards_bn' => 'nullable|string',
            'awards_ar' => 'nullable|string',
            'awards_hi' => 'nullable|string',
        ]); 

        $imgName = $this->uploadFile(3, $request->img);
        $doctor = $this->repoDoctor->store($request, $imgName);
        return redirect()->route('doctors.list')->with('success', 'Doctor created successfully!');
    }

    public function edit(Request $request, $id)
    {
        $doctor = $this->repoDoctor->find($id);
        $treatment = Treatment::where('is_delete', 0)->select('id', 'treatment_name_en')->get();
        // Fetch selected specializations for the doctor
        $selectedSpecializations = $doctor->spelizations->pluck('specialization_id')->toArray();

        if (!$treatment) {
            abort(404, 'Treatment not found');
        }

        return view('Admin.Doctor.edit')
            ->with('doctorInfo', $doctor)
            ->with('treatments', $treatment)
            ->with('selectedSpecializations', $selectedSpecializations);
    }

    public function update(Request $request, $id)
    {
        // Validate the request data
        $validatedData = $request->validate([
            'img' => 'sometimes|image|mimes:jpeg,png,jpg,gif,webp|max:2048',
            'name_en' => '|string',
            'name_bn' => 'nullable|string',
            'name_ar' => 'nullable|string',
            'name_hi' => 'nullable|string',
            'spelization_id' => '',
            'experience_en' => 'nullable|string',
            'experience_ar' => 'nullable|string',
            'experience_bn' => 'nullable|string',
            'experience_hi' => 'nullable|string',
            'hospital_id' => 'nullable',
            'fb_link' => 'nullable|url',
            'insta_link' => 'nullable|url',
            'twitter_link' => 'nullable|url',
            'linkdid' => 'nullable|url',
            'specialist_en' => 'nullable|string',
            'specialist_bn' => 'nullable|string',
            'specialist_ar' => 'nullable|string',
            'specialist_hi' => 'nullable|string',
            'about_doctor_en' => 'nullable|string',
            'about_doctor_bn' => 'nullable|string',
            'about_doctor_ar' => 'nullable|string',
            'about_doctor_hi' => 'nullable|string',
            'work_exp_his_en' => 'nullable|string',
            'work_exp_his_bn' => 'nullable|string',
            'work_exp_his_ar' => 'nullable|string',
            'work_exp_his_hi' => 'nullable|string',
            'qualification_en' => 'nullable|string',
            'qualification_bn' => 'nullable|string',
            'qualification_ar' => 'nullable|string',
            'qualification_hi' => 'nullable|string',
            'awards_en' => 'nullable|string',
            'awards_bn' => 'nullable|string',
            'awards_ar' => 'nullable|string',
            'awards_hi' => 'nullable|string',
        ]);

        $treatment = $this->repoDoctor->update($id, $request);
        return redirect()->route('doctors.list')->with('success', 'Doctor updateted successfully!');
    }

    public function update_img(Request $request, $id)
    {
        // Validate the request data
        $validatedData = $request->validate([
            'img' => 'sometimes|image|mimes:jpeg,png,jpg,gif,webp|max:2048'
        ]);

        $imgName = $this->uploadFile(3, $request->img);
        $treatment = $this->repoDoctor->update_img($id, $request, $imgName);
        return redirect()->route('doctors.list')->with('success', 'Doctor updateted successfully!');
    }

    public function delete($id)
    {
        $deletedDoctor = $this->repoDoctor->delete($id);

        if ($deletedDoctor) {
            // Handle successful soft delete
            return redirect()->route('doctors.list')->with('success', 'Doctor deleted successfully');
        } else {
            // Handle case where doctor is not found
            return redirect()->route('doctors.list')->with('error', 'Doctor not found');
        }
    }

}
