<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Treatment;
use App\Models\Hospital;
use App\Repositories\Interfaces\Hospitalinterface;
use App\Traits\FileUploadTrait;
use Illuminate\Http\Request;
use Illuminate\View\View;
use App\Models\City;
class HospitalController extends Controller
{

    use FileUploadTrait;
    private $repoHospital;

    public function __construct(Hospitalinterface $repoHospital/*,OrderInterface $repoOrder*/)
    {
        $this->repoHospital = $repoHospital;
    }

    public function list(Request $request)
    {
        $hospital = $this->repoHospital->list();

        return view('Admin.Hospital.list')
            ->with('hospitals', $hospital);
    }

    public function create(Request $request)
    {
        $treatment = Treatment::where('is_delete', 0)->where('parent_id', 0)->select('id', 'treatment_name_en')->get();
        $citys = City::where('is_delete', 0)->select('id', 'name_en')->get();

        $treatments['treatments'] = $treatment;
        $treatments['citys'] = $citys;
        return view('Admin.Hospital.create', $treatments);
    }

    public function store(Request $request)
    {

        $validatedData = $request->validate([
            'img' => 'required|image|mimes:jpeg,png,jpg,gif,webp|max:2048',

            'name_en' => 'required|string',
            'name_bn' => 'nullable|string',
            'name_ar' => 'nullable|string',
            'name_hi' => 'nullable|string',

            'content_en' => 'nullable|string',
            'content_ar' => 'nullable|string',
            'content_hi' => 'nullable|string',
            'content_bn' => 'nullable|string',

            'city_id' =>    'nullable',
            'is_top' =>     ''
        ]);

        $imgName = $this->uploadFile(6, $request->img);
        $imgName = $this->uploadFile(6, $request->logo_img);
        $hospital = $this->repoHospital->store($request, $imgName);
        return redirect()->route('hospital.list')->with('success', 'Hospital created successfully!');
    }

    public function edit(Request $request, $id)
    {
        $hospital = $this->repoHospital->find($id);
        $treatment = Treatment::where('is_delete', 0)->where('parent_id', 0)->select('id', 'treatment_name_en')->get();
        $city = City::where('is_delete', 0)->select('id', 'name_en')->get();

        // Fetch selected specializations for the doctor
        $selectedSpecializations = $hospital->treatments->pluck('specialization_id')->toArray();

        $selectedCity = $hospital->cityies->pluck('city_id')->toArray();

        if (!$treatment) {
            abort(404, 'Treatment not found');
        }

        if (!$city) {
            abort(404, 'City not found');
        }

        return view('Admin.Hospital.edit')
            ->with('hospitalInfo', $hospital)
            ->with('treatments', $treatment)
            ->with('citys', $city)
            ->with('selectedSpecializations', $selectedSpecializations)
            ->with('selectedCity', $selectedCity);
    }

    public function update(Request $request, $id)
    {
        // Validate the request data
        $validatedData = $request->validate([


            'name_en' => 'required|string',
            'name_bn' => 'nullable|string',
            'name_ar' => 'nullable|string',
            'name_hi' => 'nullable|string',

            'content_en' => 'nullable|string',
            'content_ar' => 'nullable|string',
            'content_hi' => 'nullable|string',
            'content_bn' => 'nullable|string',

            'city_id' =>    'nullable',
            'is_top' =>     ''
        ]);

        $hospital = $this->repoHospital->update($id, $request);
        return redirect()->route('hospital.list')->with('success', 'Doctor updateted successfully!');
    }

    public function update_img(Request $request, $id)
    {
        // Validate the request data
        $validatedData = $request->validate([
            'img' => 'sometimes|image|mimes:jpeg,png,jpg,gif,webp|max:2048'
        ]);

        $imgName = $this->uploadFile(6, $request->img);
        $hospital = $this->repoHospital->update_img($id, $request, $imgName);
        return redirect()->route('hospital.list')->with('success', 'Hospital Image updateted successfully!');
    }

    public function update_logo(Request $request, $id)
    {
        // Validate the request data
        $validatedData = $request->validate([
            'logo_img' => 'sometimes|image|mimes:jpeg,png,jpg,gif,webp|max:2048'
        ]);

        $imgName = $this->uploadFile(6, $request->logo_img);
        $hospital = $this->repoHospital->update_logo($id, $request, $imgName);
        return redirect()->route('hospital.list')->with('success', 'Hospital Logo updateted successfully!');
    }

    public function delete($id)
    {
        $deletedHospital = $this->repoHospital->delete($id);

        if ($deletedHospital) {
            // Handle successful soft delete
            return redirect()->route('hospital.list')->with('success', 'Doctor deleted successfully');
        } else {
            // Handle case where doctor is not found
            return redirect()->route('hospital.list')->with('error', 'Doctor not found');
        }
    }

}
