<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Treatment;
use App\Models\Hospital;
use App\Repositories\Interfaces\Testimonialsinterface;
use App\Traits\FileUploadTrait;
use Illuminate\Http\Request;
use Illuminate\View\View;
use App\Models\City;
class TestimonialsController extends Controller
{

    use FileUploadTrait;
    private $repoTestimonials;

    public function __construct(Testimonialsinterface $repoTestimonials/*,OrderInterface $repoOrder*/)
    {
        $this->repoTestimonials = $repoTestimonials;
    }

    public function list(Request $request)
    {
        $testimonial = $this->repoTestimonials->list();

        return view('Admin.Testimonial.list')
            ->with('testimonials', $testimonial);
    }

    public function create(Request $request)
    {
        return view('Admin.Testimonial.create');
    }

    public function store(Request $request)
    {

        $validatedData = $request->validate([
            'img' => 'required|image|mimes:jpeg,png,jpg,gif,webp|max:2048',

            'name_en' => 'required|string',
            'name_bn' => 'nullable|string',
            'name_ar' => 'nullable|string',
            'name_hi' => 'nullable|string',


        ]);

        $imgName = $this->uploadFile(7, $request->img);
        $testimonial = $this->repoTestimonials->store($request, $imgName);
        return redirect()->route('testimonials.list')->with('success', 'Testimonials created successfully!');
    }

    public function edit(Request $request, $id)
    {
        $testimonial = $this->repoTestimonials->find($id);



        return view('Admin.Testimonial.edit')
            ->with('testimonialInfo', $testimonial);

    }

    public function update(Request $request, $id)
    {
        // Validate the request data
        $validatedData = $request->validate([


            'name_en' => 'required|string',
            'name_bn' => 'nullable|string',
            'name_ar' => 'nullable|string',
            'name_hi' => 'nullable|string',


        ]);

        $hospital = $this->repoTestimonials->update($id, $request);
        return redirect()->route('testimonials.list')->with('success', 'Doctor updateted successfully!');
    }

    public function update_img(Request $request, $id)
    {
        // Validate the request data
        $validatedData = $request->validate([
            'img' => 'sometimes|image|mimes:jpeg,png,jpg,gif,webp|max:2048'
        ]);

        $imgName = $this->uploadFile(7, $request->img);
        $hospital = $this->repoTestimonials->update_img($id, $request, $imgName);
        return redirect()->route('testimonials.list')->with('success', 'Hospital Image updateted successfully!');
    }



    public function delete($id)
    {
        $deletedHospital = $this->repoTestimonials->delete($id);

        if ($deletedHospital) {
            // Handle successful soft delete
            return redirect()->route('testimonials.list')->with('success', 'Doctor deleted successfully');
        } else {
            // Handle case where doctor is not found
            return redirect()->route('testimonials.list')->with('error', 'Doctor not found');
        }
    }

}
