<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Repositories\Interfaces\Treatmentinterface;
use App\Traits\FileUploadTrait;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\View\View;

class TreatmentController extends Controller
{
    use FileUploadTrait;
    private $repoTreatment;

    public function __construct(Treatmentinterface $repoTreatment/*,OrderInterface $repoOrder*/)
    {
        $this->repoTreatment = $repoTreatment;
    }

    public function list(Request $request)
    {
        $treatments = $this->repoTreatment->list();

        return view('Admin.Treatment.list')
            ->with('treatmentInfo', $treatments);
    }

    public function create(Request $request)
    {

        return view('Admin.Treatment.create');
    }

    public function store(Request $request)
    {
        // Validate the request data
        $validatedData = $request->validate([
            'treatment_name_en' => 'nullable|string',
           

            'description_en' => 'nullable|string',


            'content_en' => 'nullable|string',


            'is_popular' => 'nullable|boolean',
            'is_current' => 'nullable|boolean',
            'img' => 'image|mimes:jpeg,png,jpg,gif,webp|max:2048',
            'icon' => 'image|mimes:jpeg,png,jpg,gif,webp|max:2048',
        ]);

        $imgName = $this->uploadFile(5, $request->img);
        $imgNameIcon = $this->uploadFile(5, $request->icon);

        $treatment = $this->repoTreatment->store($request, $imgName, $imgNameIcon);
        return redirect()->route('treatment.list')->with('success', 'Treatment created successfully!');
    }

    public function edit(Request $request, $id)
    {
        $treatment = $this->repoTreatment->find($id);

        if (!$treatment) {
            abort(404, 'Treatment not found');
        }

        return view('Admin.Treatment.edit')
            ->with('treatmentInfo', $treatment);
    }

    public function view(Request $request, $id)
    {
        $treatment = $this->repoTreatment->find($id);
        if (!$treatment) {
            abort(404, 'Treatment not found');
        }

        // Fetch treatments with the same parent_id as the current treatment's ID
        // Fetch child treatments using the repository
        $childTreatments = $this->repoTreatment->getChildTreatments($id);

        return view('Admin.Treatment.view')
            ->with('treatmentInfo', $treatment)
            ->with('childTreatments', $childTreatments);
    }

    public function update(Request $request, $id)
    {
        // Validate the request data
        $validatedData = $request->validate([
            'treatment_name_en' => 'nullable|string',

            'description_en' => 'nullable|string',


            'content_en' => 'nullable|string',

            'is_popular' => 'nullable|boolean',
            'is_current' => 'nullable|boolean',
            'img' => 'image|mimes:jpeg,png,jpg,gif,webp|max:2048',
            'icon' => 'image|mimes:jpeg,png,jpg,gif,webp|max:2048',
        ]);

        $imgName = $this->uploadFile(5, $request->img);
        $imgNameIcon = $this->uploadFile(5, $request->icon);
        // $treatment = $this->repoTreatment->update($validatedData);

        $treatment = $this->repoTreatment->update($id, $request, $imgName, $imgNameIcon);

        return redirect()->route('treatment.list')->with('success', 'Treatment updateted successfully!');
    }

    public function childrenTreatmentCreate(Request $request, $id): View
    {
        $parentTreatment = $this->repoTreatment->find($id);

        if (!$parentTreatment) {
            abort(404, 'Parent Treatment not found');
        }

        return view('Admin.Treatment.children_create', ['parentTreatment' => $parentTreatment]);
    }

    public function childrenTreatmentStore(Request $request, $id)
    {
        // Set the parent_id based on the provided $id
        $request->merge(['parent_id' => $id]);

        // Set default values for fields that might be null
        $request->merge([
            'is_popular' => $request->has('is_popular') ? $request->input('is_popular') : 0,
            'is_current' => $request->has('is_current') ? $request->input('is_current') : 0,
        ]);

        // Validate the request data
        $validatedData = $request->validate([
            'treatment_name_en' => 'nullable|string',
            'treatment_name_bn' => 'nullable|string',
            'treatment_name_hi' => 'nullable|string',
            'treatment_name_ar' => 'nullable|string',

            'description_en' => 'nullable|string',
            'description_ar' => 'nullable|string',
            'description_bn' => 'nullable|string',
            'description_hi' => 'nullable|string',

            'content_en' => 'nullable|string',
            'content_bn' => 'nullable|string',
            'content_hi' => 'nullable|string',
            'content_ar' => 'nullable|string',

            'is_popular' => 'boolean',
            'is_current' => 'boolean',
            'img' => 'image|mimes:jpeg,png,jpg,gif,webp|max:2048',
            'icon' => 'image|mimes:jpeg,png,jpg,gif,webp|max:2048',
        ]);

        $imgName = $this->uploadFile(5, $request->img);
        $imgNameIcon = $this->uploadFile(5, $request->icon);

        $this->repoTreatment->store($request, $imgName, $imgNameIcon);
        return redirect()->route('treatment.view', ['id' => $id])
            ->with('success', 'Child Treatment created successfully!');
    }

    public function childrenTreatmentEdit(Request $request, $id): View
    {
        $childTreatment = $this->repoTreatment->find($id);

        if (!$childTreatment) {
            abort(404, 'Child Treatment not found');
        }

        return view('Admin.Treatment.children_treatment_edit')
            ->with('treatmentInfo', $childTreatment);
    }

    public function childrenTreatmentUpdate(Request $request, $id): RedirectResponse
    {
          // Set default values for fields that might be null
          $request->merge([
            'is_popular' => $request->has('is_popular') ? $request->input('is_popular') : 0,
            'is_current' => $request->has('is_current') ? $request->input('is_current') : 0,
        ]);
        // Validate the request data
        $validatedData = $request->validate([
            'treatment_name_en' => 'nullable|string',
            'treatment_name_bn' => 'nullable|string',
            'treatment_name_hi' => 'nullable|string',
            'treatment_name_ar' => 'nullable|string',

            'description_en' => 'nullable|string',
            'description_ar' => 'nullable|string',
            'description_bn' => 'nullable|string',
            'description_hi' => 'nullable|string',

            'content_en' => 'nullable|string',
            'content_bn' => 'nullable|string',
            'content_hi' => 'nullable|string',
            'content_ar' => 'nullable|string',

            'is_popular' => 'boolean',
            'is_current' => 'boolean',
            'img' => 'image|mimes:jpeg,png,jpg,gif,webp|max:2048',
            'icon' => 'image|mimes:jpeg,png,jpg,gif,webp|max:2048',
        ]);

        $imgName = $this->uploadFile(5, $request->img);
        $imgNameIcon = $this->uploadFile(5, $request->icon);

        // Update the child treatment
        $childTreatment = $this->repoTreatment->update($id, $request, $imgName, $imgNameIcon);

        if (!$childTreatment) {
            abort(404, 'Child Treatment not found');
        }

        return redirect()->route('treatment.view', $childTreatment->parent_id)
            ->with('success', 'Child Treatment updated successfully!');
    }


    public function delete($id)
    {
        $deletedTreatment = $this->repoTreatment->delete($id);

        if ($deletedTreatment) {
            // Handle successful soft delete
            return redirect()->route('treatment.list')->with('success', 'Treatment deleted successfully');
        } else {
            // Handle case where doctor is not found
            return redirect()->route('treatment.list')->with('error', 'Treatment not found');
        }
    }

}
