<?php

namespace App\Http\Controllers\Hr;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\UserRoleMaster;
use Auth;
use DB;
use Illuminate\Http\Request;
use Validator;

class StaffController extends Controller
{

    public function index(request $request)
    {

        $list = User::select(DB::raw("concat(first_name, ' ', last_name) as name")
            , 'id', 'phone_number', 'role_id', 'email', 'status', 'is_delete', 'is_super_user', DB::raw('id, lpad(id, 10, 0) as ref'))
            ->where('is_delete', 0)
            ->with(['role' => function ($query) {
                $query->select('id', 'name');
            }])
            ->orderBy('id', 'DESC')
            ->paginate(10);

        $data['records'] = $list;
        //echo json_encode($list);
        //return;
        $list->map(function ($item) {
            $item['ref'] = "USR" . $item->ref;
            if ($item->role != null) {
                $item['role_name'] = $item->role->name;
            } else {
                $item['role_name'] = "NA";
            }

            unset($item->role);
        });

        //echo json_encode($data);
        //return;

        return view('hr.staff.list', $data);
    }

    public function create(request $request)
    {
        /*==============Role List===============*/
        $list = UserRoleMaster::select('id', 'name')
            ->where('is_delete', 0)
            ->where('status', 1)
            ->where('has_create_by_admin', 1)
            ->orderBy('name', 'ASC')
            ->get();

        $data['records'] = $list;

        return view('hr.staff.create', $data);
    }

    public function view($id)
    {

        return \Redirect::Route('hr.staff.view.uuid', $this->getMaskId($id));

    }

    public function viewByUuid($id)
    {
        $data['uuid'] = $id;
        $id = $this->getId($id);
        $record = User::select(DB::raw("concat(first_name, ' ', last_name) as name")
            , 'first_name', 'last_name'
            , 'id', 'phone_number', 'role_id', 'email', 'status', 'is_delete', 'is_super_user'
            , DB::raw('id, lpad(id, 10, 0) as ref')
            , DB::raw('DATE_FORMAT(created_at, "%d/%m/%Y") as join_date'))
            ->where('is_delete', 0)
            ->where('id', $id)
            ->with(['role' => function ($query) {
                $query->select('id', 'name');
            }])
            ->orderBy('id', 'DESC')
            ->first();

        $record['ref'] = "USR" . $record->ref;

        $record['acc_status'] = ($record->status == 1) ? 'Active' : 'In-Active';

        $data['record'] = $record;

        $list = UserRoleMaster::select('id', 'name')
            ->where('is_delete', 0)
            ->where('status', 1)
            ->where('has_create_by_admin', 1)
            ->orderBy('name', 'ASC')
            ->get();

        $data['roles'] = $list;
        return view('hr.staff.view', $data);
    }

    public function staffCreate(Request $request)
    {

        $validator = Validator::make($request->all(),
            [
                'first_name' => 'required|max:250',
                'last_name' => 'required|max:250',
                'email' => 'required|max:150|unique:users,email',
                'phone_number' => 'required|max:11|min:8|unique:users,phone_number',
                'password' => 'required|min:6|max:25',
                'role_id' => 'required|not_in:Select Role',

            ]

        );

        if ($validator->fails()) {
            return \Redirect::back()->withErrors($validator->errors()->all());
        }

        try {
            $model = new User;
            $model->first_name = $request->first_name;
            $model->last_name = $request->last_name;
            $model->email = $request->email;
            $model->phone_number = $request->phone_number;
            $model->password = $request->password;
            $model->role_id = $request->role_id;
            $model->created_by = Auth::user()->id;
            if (isset($request->status)) {
                $model->status = 1;
            } else {
                $model->status = 0;
            }

            $model->save();

            return \Redirect::Route('hr.staff')->with('success', 'Record added Successfully');
        } catch (Exception $e) {
            throw new \App\Exceptions\AdminException($e->getMessage());
        }

    }

    public function updateAccountStatus(request $request)
    {
        $uuid = $request->id;

        $id = $this->getId($uuid);

        $model = User::find($id);

        $model->status = $request->status;

        $model->save();

        return \Redirect::Route('hr.staff.view.uuid', $uuid)->with('success', 'Account Status Updated Successfully');
    }

    public function updatePassword(request $request)
    {
        $validator = Validator::make($request->all(),
            ['password' => 'required|min:8',
                'confirm_password' => 'required|min:8|required_with:password|same:password']
        );
        if ($validator->fails()) {
            return \Redirect::back()->withErrors($validator->errors()->all());
        }

        $uuid = $request->id;

        $id = $this->getId($uuid);

        $model = User::find($id);

        $model->password = $request->password;

        $model->save();

        return \Redirect::Route('hr.staff.view.uuid', $uuid)->with('success', 'Password Updated Successfully');
    }

    public function updateProfile(request $request)
    {

        $uuid = $request->id;
        $id = $this->getId($uuid);

        $validator = Validator::make($request->all(),
            [
                'first_name' => 'required|max:250',
                'last_name' => 'required|max:250',
                'phone_number' => 'required|max:11|min:8|unique:users,phone_number,' . $id,
                'role_id' => 'required|not_in:Select Role',

            ]

        );

        if ($validator->fails()) {
            return \Redirect::back()->withErrors($validator->errors()->all());
        }

        $model = User::find($id);
        $model->first_name = $request->first_name;
        $model->last_name = $request->last_name;
        $model->phone_number = $request->phone_number;
        $model->role_id = $request->role_id;
        $model->save();

        return \Redirect::route('hr.staff.view.uuid', $uuid)->with('success', 'Profile Updated Successfully');

    }


    public function deleteAccount(request $request)
    {

        $time=time();
        $uuid = $request->id;
        $id = $this->getId($uuid);


        $model = User::find($id);
        $model->phone_number = $time. '_DEL_'.$model->phone_number;
        $model->email =$time. '_DEL_'.$model->email;
        $model->is_delete=1;
        $model->save();

        return \Redirect::route('hr.staff', $uuid)->with('success', "$model->first_name $model->last_name's profile removed from the system Successfully");

    }
}
