<?php

namespace App\Http\Controllers\website;

use App;
use App\Http\Controllers\Controller;
use App\Repositories\Interfaces\UserInterface;
use App\WebRepositories\Interfaces\CmsInterface;
use App\WebRepositories\Interfaces\EnqueryInterface;
use App\WebRepositories\Interfaces\HospitalInterface;
use App\WebRepositories\Interfaces\NewslatterInterface;
use App\WebRepositories\Interfaces\SiteSettingInterface;
use App\WebRepositories\Interfaces\Treatmentinterface;
use App\WebRepositories\Interfaces\DoctorInterface;
use App\WebRepositories\Interfaces\Testimonialsinterface;
use Illuminate\Http\Request;

class HomeController extends Controller
{

    private $repoUser;
    private $repoEnquery;
    private $repoNewslatter;
    private $repoSiteSetting;
    private $repoTreatment;
    private $repoCms;
    private $repoHospital;
    private $repoDoctor;
    private $repoTestimonials;

    public function __construct(UserInterface $repoUser
        , EnqueryInterface $repoEnquery
        , NewslatterInterface $repoNewslatter
        , SiteSettingInterface $repoSiteSetting
        , Treatmentinterface $repoTreatment
        , CmsInterface $repoCms
        , HospitalInterface $repoHospital, DoctorInterface $repoDoctor , Testimonialsinterface $repoTestimonials) {

        $this->repoUser = $repoUser;
        $this->repoEnquery = $repoEnquery;
        $this->repoNewslatter = $repoNewslatter;
        $this->repoSiteSetting = $repoSiteSetting;
        $this->repoTreatment = $repoTreatment;
        $this->repoCms = $repoCms;
        $this->repoHospital = $repoHospital;
        $this->repoDoctor = $repoDoctor;
        $this->repoTestimonials = $repoTestimonials;

    }

    public function index(request $request)
    {

        $siteInfo = $this->repoSiteSetting->getHeaderFooterData();

        $treatments = $this->repoTreatment->getTreatmentListByLimit(6);

        $aboutUs = $this->repoCms->getAboutUs();

        $topHospitals = $this->repoHospital->getTopListByLimit(10);

        $topDoctors = $this->repoDoctor->getTopListByLimit(10);

        $testimonilas = $this->repoTestimonials->getTestimonialsListByLimit(20);

        return view('website.home')
            ->with('siteInfo', $siteInfo)
            ->with('treatments', $treatments)
            ->with('aboutUs', $aboutUs)
            ->with('topHospitals', $topHospitals)
            ->with('topDoctors', $topDoctors)
            ->with('testimonials', $testimonilas);
    }

    public function newslatterSubscribe(Request $request)
    {
        $this->repoNewslatter->store($request);
        return redirect()->back()
            ->with("success"
                , "Thanks for your newslatter subscription. You can get updates on your email.");

    }
    public function changeLanguage(Request $request)
    {

        session()->put('locale', $request->locale);
        return redirect()->back();
    }

    public function submitEnquery(Request $request)
    {
        $request->validate(['name' => 'required|max:250'
            , 'email' => 'max:150'
            , 'phone_number' => 'required|digits_between:8,12'
            , 'enquery_for' => 'max:250'
            , 'message' => 'max:250']);

        $this->repoEnquery->store($request);

        return redirect()->back()
            ->with("success"
                , "Enquery Submitted Successfully. We will contact you soon.");
    }

    public function contact(Request $request)
    {
        $siteInfo = $this->repoSiteSetting->getHeaderFooterData();
        return view('website.contact')->with('siteInfo', $siteInfo);
    }

    public function cms($label, Request $request)
    {
        switch ($label) {

            case "medical-visa":
                $record = $this->repoCms->getCms(1);
                break;
            case "treatment-cost-comparison":
                $record = $this->repoCms->getCms(2);
                break;
            case "medical-insurance":
                $record = $this->repoCms->getCms(3);
                break;
            case "medical-process":
                $record = $this->repoCms->getCms(4);
                break;
            case "about-us":
                $record = $this->repoCms->getCms(5);
                break;
            default:
                // Handle default case, if needed
                break;
        }

        $currentoptions = $this->repoTreatment->getTreatmentCurrentOptios($request);
        $poppulars = $this->repoTreatment->getTreatmentpopular($request);

        return view('website.cms')
        ->with('record', $record)
        ->with('current_options', $currentoptions)
        ->with('populars_treatments', $poppulars);

    }
}
