<?php
namespace App\Repositories;
use App\Models\Country;
use App\Models\City;
use App\Repositories\Interfaces\Countryinterface;
use App\Traits\FileUploadTrait;
use Illuminate\Http\Request;
use Log;

class ContryRepository implements Countryinterface
{
    use FileUploadTrait;
    public function store(Request $request, $imgName, $imgNameIcon)
    {
        $treatment = new Country;
        $treatment->name_en = $request->input('name_en');
        $treatment->description = $request->input('description');
        $treatment->flag_img = $imgName;
        $treatment->country_img = $imgNameIcon;

        $treatment->save();

        return $treatment;

    }

    public function storeCity(Request $request, $imgName)
    {
        $treatment = new City;
        $treatment->name_en = $request->input('name_en');
        $treatment->country_id = $request->input('country_id');
        $treatment->description = $request->input('description');
        $treatment->img = $imgName;
        $treatment->save();

        return $treatment;

    }


    public function list()
    {

        $list = Country::select('id', 'name_en', 'flag_img', 'country_img', 'description', 'is_delete', 'status')
            ->where('is_delete', 0)
            ->withCount(['cities' => function ($query) {
                $query->where('is_delete', 0); // Count only active cities
            }])
            ->get();
        Log::info($list);

        $baseImgPath = $this->getBasePath();
        $list->map(function ($item) use ($baseImgPath) {
            if ($item->flag_img != null) {
                $item['flag_img'] = $baseImgPath . $item->flag_img;
                $item['country_img'] = $baseImgPath . $item->country_img;
            } else {
                $item['flag_img'] = null;
                $item['country_img'] = null;
            }
        });

        return $list;

    }




    public function listCity($id)
    {

        $list = City::select('id', 'name_en', 'img',  'description', 'is_delete', 'status_id', 'country_id')
            ->where('country_id', $id)
            ->where('is_delete', 0)
            ->get();
        Log::info($list);

        $baseImgPath = $this->getBasePath();
        $list->map(function ($item) use ($baseImgPath) {
            if ($item->img != null) {
                $item['img'] = $baseImgPath . $item->img;
            } else {
                $item['img'] = null;
            }
        });

        return $list;

    }

    public function find($id)
    {
        $treatment = Country::find($id);
        $baseImgPath = $this->getBasePath();
        if ($treatment->flag_img != null) {
            $treatment['flag_img'] = $baseImgPath . $treatment->flag_img;
            $treatment['country_img'] = $baseImgPath . $treatment->country_img;
        } else {
            $treatment['flag_img'] = null;
            $treatment['country_img'] = null;
        }
        Log::info($treatment);
        return $treatment;

    }

    public function update($id, Request $request, $imgName, $imgNameIcon)
    {
        $treatment = Country::find($request->id);
        // Check if the doctor record exists
        if (!$treatment) {
            return response()->json(['error' => 'Doctor not found'], 404);
        }

        $treatment->name_en = $request->input('name_en');
        $treatment->description = $request->input('description');


        $treatment->flag_img = $imgName;
        $treatment->country_img = $imgNameIcon;

        $treatment->save();

        return $treatment;
    }


    public function updateCity($id, Request $request, $imgName)
    {
        $treatment = City::find($request->id);
        // Check if the doctor record exists
        if (!$treatment) {
            return response()->json(['error' => 'Doctor not found'], 404);
        }
        $treatment->name_en = $request->input('name_en');
        $treatment->img = $imgName;
        $treatment->save();

        return $treatment;
    }

    public function getChildTreatments($parentId)
    {
        // Treatment::where('parent_id', $parentId)->get();
        $list = Treatment::select('id', 'treatment_name_en', 'img', 'icon', 'is_delete')
            ->where('parent_id', $parentId)
            ->where('is_delete', 0)
            ->get();
        Log::info($list);

        $baseImgPath = $this->getBasePath();
        $list->map(function ($item) use ($baseImgPath) {
            if ($item->img != null) {
                $item['img'] = $baseImgPath . $item->img;
                $item['icon'] = $baseImgPath . $item->icon;
            } else {
                $item['img'] = null;
                $item['icon'] = null;
            }
        });

        return $list;
    }

    public function delete($id)
    {
        $treatment = Country::find($id);

        if (!$treatment) {
            return null; // or handle the case where doctor is not found
        }

        // Perform soft delete by updating the is_delete field
        $treatment->update(['is_delete' => 1]);

        return $treatment;
    }
    public function deleteCity($id)
    {
        $treatment = City::find($id);

        if (!$treatment) {
            return null; // or handle the case where doctor is not found
        }

        // Perform soft delete by updating the is_delete field
        $treatment->update(['is_delete' => 1]);

        return $treatment;
    }
}
