<?php

namespace App\Repositories;

use App\Models\Doctor;
use App\Models\SpecializationMapping;
use App\Repositories\Interfaces\Doctorinterface;
use App\Traits\FileUploadTrait;
use Illuminate\Http\Request;
use Log;

class DoctorRepository implements Doctorinterface
{

    use FileUploadTrait;
    public function list()
    {

        $list = Doctor::with(['spelizations.spelization' => function ($query) {
            $query->select('id', 'treatment_name_en');
        }])
            ->select('id', "name_en", 'img', 'is_delete')
            ->where('is_delete', 0)
            ->get();
        Log::info($list);

        $baseImgPath = $this->getBasePath();
        $list->map(function ($item) use ($baseImgPath) {
            if ($item->img != null) {
                $item['profile_pic_url'] = $baseImgPath . $item->img;
            } else {
                $item['profile_pic_url'] = null;
            }

            unset($item->img, $item->is_delete);
        });

        return $list;

    }

    public function find($id)
    {
        $doctor = Doctor::find($id);
        $baseImgPath = $this->getBasePath();
        if ($doctor->img != null) {
            $doctor['profile_pic_url'] = $baseImgPath . $doctor->img;
        } else {
            $doctor['profile_pic_url'] = null;
        }
        Log::info($doctor);
        return $doctor;
    }

    public function store(Request $request, $imgName)
    {
        $doctor = new Doctor;

        $doctor->name_en = $request->name_en;
        $doctor->name_bn = $request->input('name_bn');
        $doctor->name_ar = $request->input('name_ar');
        $doctor->name_hi = $request->input('name_hi');
        $doctor->experience_en = $request->input('experience_en');
        $doctor->experience_bn = $request->input('experience_bn');
        $doctor->experience_ar = $request->input('experience_ar');
        $doctor->experience_hi = $request->input('experience_hi');
        $doctor->hospital_id = $request->input('hospital_id');
        $doctor->fb_link = $request->input('fb_link');
        $doctor->insta_link = $request->input('insta_link');
        $doctor->twitter_link = $request->input('twitter_link');
        $doctor->linkdid = $request->input('linkdid');
        $doctor->specialist_en = $request->input('specialist_en');
        $doctor->specialist_bn = $request->input('specialist_bn');
        $doctor->specialist_ar = $request->input('specialist_ar');
        $doctor->specialist_hi = $request->input('specialist_hi');
        $doctor->about_doctor_en = $request->input('about_doctor_en');
        $doctor->about_doctor_bn = $request->input('about_doctor_bn');
        $doctor->about_doctor_ar = $request->input('about_doctor_ar');
        $doctor->about_doctor_hi = $request->input('about_doctor_hi');
        $doctor->work_exp_his_en = $request->input('work_exp_his_en');
        $doctor->work_exp_his_bn = $request->input('work_exp_his_bn');
        $doctor->work_exp_his_ar = $request->input('work_exp_his_ar');
        $doctor->work_exp_his_hi = $request->input('work_exp_his_hi');
        $doctor->qualification_en = $request->input('qualification_en');
        $doctor->qualification_bn = $request->input('qualification_bn');
        $doctor->qualification_ar = $request->input('qualification_ar');
        $doctor->qualification_hi = $request->input('qualification_hi');
        $doctor->awards_en = $request->input('awards_en');
        $doctor->awards_bn = $request->input('awards_bn');
        $doctor->awards_ar = $request->input('awards_ar');
        $doctor->awards_hi = $request->input('awards_hi');
        $doctor->is_top = $request->input('is_top');

        $doctor->img = $imgName;

        $doctor->save();
        $sid = $request->spelization_id;

        if (isset($sid)) {

            $temp = [];
            foreach ($sid as $itemId) {

                array_push($temp, ["specialization_id" => $itemId, "doctor_id" => $doctor->id]);

            }
 
            SpecializationMapping::insert($temp);

        }

        return $doctor;
    }

    public function update_img($id, Request $request, $imgName)
    {
        $doctor = Doctor::find($request->id);
        if (!$doctor) {
            return response()->json(['error' => 'Doctor not found'], 404);
        }
        $doctor->img = $imgName;
        $doctor->save();
    }

    public function update($id, Request $request)
    {
        // Find the existing doctor record by ID
        $doctor = Doctor::find($request->id);

        // Check if the doctor record exists
        if (!$doctor) {
            return response()->json(['error' => 'Doctor not found'], 404);
        }
        // Update the doctor attributes with values from the request
        $doctor->name_en = $request->input('name_en');
        $doctor->name_bn = $request->input('name_bn');
        $doctor->name_ar = $request->input('name_ar');
        $doctor->name_hi = $request->input('name_hi');

        $doctor->experience_en = $request->input('experience_en');
        $doctor->experience_bn = $request->input('experience_bn');
        $doctor->experience_ar = $request->input('experience_ar');
        $doctor->experience_hi = $request->input('experience_hi');

        $doctor->hospital_id = $request->input('hospital_id');

        $doctor->fb_link = $request->input('fb_link');
        $doctor->insta_link = $request->input('insta_link');
        $doctor->twitter_link = $request->input('twitter_link');
        $doctor->linkdid = $request->input('linkdid');

        $doctor->specialist_en = $request->input('specialist_en');
        $doctor->specialist_bn = $request->input('specialist_bn');
        $doctor->specialist_ar = $request->input('specialist_ar');
        $doctor->specialist_hi = $request->input('specialist_hi');

        $doctor->about_doctor_en = $request->input('about_doctor_en');
        $doctor->about_doctor_bn = $request->input('about_doctor_bn');
        $doctor->about_doctor_ar = $request->input('about_doctor_ar');
        $doctor->about_doctor_hi = $request->input('about_doctor_hi');
        $doctor->work_exp_his_en = $request->input('work_exp_his_en');
        $doctor->work_exp_his_bn = $request->input('work_exp_his_bn');
        $doctor->work_exp_his_ar = $request->input('work_exp_his_ar');
        $doctor->work_exp_his_hi = $request->input('work_exp_his_hi');
        $doctor->qualification_en = $request->input('qualification_en');
        $doctor->qualification_bn = $request->input('qualification_bn');
        $doctor->qualification_ar = $request->input('qualification_ar');
        $doctor->qualification_hi = $request->input('qualification_hi');
        $doctor->awards_en = $request->input('awards_en');
        $doctor->awards_bn = $request->input('awards_bn');
        $doctor->awards_ar = $request->input('awards_ar');
        $doctor->awards_hi = $request->input('awards_hi');
        //$doctor->is_top = $request->input('is_top');

        $doctor->is_top = $request->has('is_top') ? true : false;

        // Save the updated doctor record

        $doctor->save();
        // Update specialization mapping if specialization IDs are provided
        $sid = $request->input('specialization_id');

        if (isset($sid)) {
            $temp = [];
            foreach ($sid as $itemId) {
                array_push($temp, ["specialization_id" => $itemId, "doctor_id" => $doctor->id]);
            }
            // Delete existing mappings for the current doctor
            SpecializationMapping::where('doctor_id', $doctor->id)->delete();

            // Insert new mappings
            SpecializationMapping::insert($temp);
        }

        return $doctor;
    }

    public function update_profile_pic(Request $request)
    {
        // Find the existing doctor record by ID
        $doctor = Doctor::find($request->id);

        // Check if the doctor record exists
        if (!$doctor) {
            return response()->json(['error' => 'Doctor not found'], 404);
        }

        // Update the doctor attributes with values from the request
        $doctor->name_en = $request->input('name_en');
        $doctor->name_bn = $request->input('name_bn');
        $doctor->name_ar = $request->input('name_ar');
        $doctor->name_hi = $request->input('name_hi');

        $doctor->experience_en = $request->input('experience_en');
        $doctor->experience_bn = $request->input('experience_bn');
        $doctor->experience_ar = $request->input('experience_ar');
        $doctor->experience_hi = $request->input('experience_hi');

        $doctor->hospital_id = $request->input('hospital_id');

        $doctor->fb_link = $request->input('fb_link');
        $doctor->insta_link = $request->input('insta_link');
        $doctor->twitter_link = $request->input('twitter_link');
        $doctor->linkdid = $request->input('linkdid');

        $doctor->specialist_en = $request->input('specialist_en');
        $doctor->specialist_bn = $request->input('specialist_bn');
        $doctor->specialist_ar = $request->input('specialist_ar');
        $doctor->specialist_hi = $request->input('specialist_hi');

        $doctor->about_doctor_en = $request->input('about_doctor_en');
        $doctor->about_doctor_bn = $request->input('about_doctor_bn');
        $doctor->about_doctor_ar = $request->input('about_doctor_ar');
        $doctor->about_doctor_hi = $request->input('about_doctor_hi');
        $doctor->work_exp_his_en = $request->input('work_exp_his_en');
        $doctor->work_exp_his_bn = $request->input('work_exp_his_bn');
        $doctor->work_exp_his_ar = $request->input('work_exp_his_ar');
        $doctor->work_exp_his_hi = $request->input('work_exp_his_hi');
        $doctor->qualification_en = $request->input('qualification_en');
        $doctor->qualification_bn = $request->input('qualification_bn');
        $doctor->qualification_ar = $request->input('qualification_ar');
        $doctor->qualification_hi = $request->input('qualification_hi');
        $doctor->awards_en = $request->input('awards_en');
        $doctor->awards_bn = $request->input('awards_bn');
        $doctor->awards_ar = $request->input('awards_ar');
        $doctor->awards_hi = $request->input('awards_hi');

        // Save the updated doctor record
        $doctor->save();

        // Update specialization mapping if specialization IDs are provided
        $sid = $request->specialization_id;

        if (isset($sid)) {
            $temp = [];
            foreach ($sid as $itemId) {
                array_push($temp, ["specialization_id" => $itemId, "doctor_id" => $doctor->id]);
            }

            // Delete existing mappings for the current doctor
            SpecializationMapping::where('doctor_id', $doctor->id)->delete();

            // Insert new mappings
            SpecializationMapping::insert($temp);
        }

        return $doctor;
    }

    public function update__($id, array $data)
    {
        $doctor = Doctor::find($id);
        if (!$doctor) {
            return null; // or handle the case where treatment is not found
        }
        $doctor->update($data);
        return $doctor;
    }

    public function delete($id)
    {
        $doctor = Doctor::find($id);

        if (!$doctor) {
            return null; // or handle the case where doctor is not found
        }

        // Perform soft delete by updating the is_delete field
        $doctor->update(['is_delete' => 1]);

        return $doctor;
    }

}
