<?php

namespace App\Repositories;

use App\Models\Doctor;
use App\Models\SpecializationMapping;
use App\Models\Hospital;
use App\Models\TreatmentMapping;
use App\Repositories\Interfaces\Hospitalinterface;
use App\Traits\FileUploadTrait;
use Illuminate\Http\Request;
use App\Models\CityMapping;
use Log;

class HospitalRepository implements Hospitalinterface
{

    use FileUploadTrait;

    public function list()
    {
        $list = Hospital::with(['treatments.treatment' => function ($query) {
            $query->select('id', 'treatment_name_en');
        }])
            ->select('id', "name_en", 'logo_img', 'img', 'is_delete')
            ->where('is_delete', 0)
            ->orderBy('id', 'DESC')
            ->get();
        Log::info($list);

        $baseImgPath = $this->getBasePath();
        $list->map(function ($item) use ($baseImgPath) {
            if ($item->img != null) {
                $item['img'] = $baseImgPath . $item->img;
                $item['logo_img'] = $baseImgPath . $item->logo_img;
            } else {
                $item['img'] = null;
                $item['logo_img'] = null;
            }


        }); 

        return $list;

    }

    public function find($id)
    {
        $hospital = Hospital::find($id);

        $baseImgPath = $this->getBasePath();
        if ($hospital->img != null) {
            $hospital['img'] = $baseImgPath . $hospital->img;
        } else {
            $hospital['img'] = null;
        }

        $baseImgPath = $this->getBasePath();
        if ($hospital->logo_img != null) {
            $hospital['logo_img'] = $baseImgPath . $hospital->logo_img;
        } else {
            $hospital['logo_img'] = null;
        }

        Log::info($hospital);
        return $hospital;
    }

    public function store(Request $request, $imgName, $imgLogo)
    {
        $hospital = new Hospital;

        $hospital->name_en = $request->name_en;
        $hospital->name_bn = $request->input('name_bn');
        $hospital->name_ar = $request->input('name_ar');
        $hospital->name_hi = $request->input('name_hi');

        $hospital->content_en = $request->input('content_en');
        $hospital->content_ar = $request->input('content_ar');
        $hospital->content_hi = $request->input('content_hi');


        $hospital->is_top = $request->input('is_top');


        $hospital->img = $imgName;
        $hospital->logo_img = $imgLogo;

        $hospital->save();
        $sid = $request->spelization_id;


        if (isset($sid)) {

            $temp = [];
            foreach ($sid as $itemId) {

                array_push($temp, ["specialization_id" => $itemId, "hospital_id" => $hospital->id]);

            }

            TreatmentMapping::insert($temp);

        }


        $cityd = $request->city_id;
        if (isset($cityd)) {

            $temp = [];
            foreach ($cityd as $itemId) {

                array_push($temp, ["city_id" => $itemId, "hospital_id" => $hospital->id]);

            }

            CityMapping::insert($temp);

        }

        return $hospital;
    }


    public function update_img($id, Request $request, $imgName){
        $hospital = Hospital::find($request->id);
        if (!$hospital) {
            return response()->json(['error' => 'Hospital not found'], 404);
        }
        $hospital->img = $imgName;
        $hospital->save();
    }


    public function update_logo($id, Request $request, $imgName){
        $hospital = Hospital::find($request->id);
        if (!$hospital) {
            return response()->json(['error' => 'Hospital not found'], 404);
        }
        $hospital->logo_img = $imgName;
        $hospital->save();
    }

    public function update($id, Request $request)
    {
        // Find the existing doctor record by ID
        $hospital = Hospital::find($request->id);

        // Check if the doctor record exists
        if (!$hospital) {
            return response()->json(['error' => 'Doctor not found'], 404);
        }
        // Update the doctor attributes with values from the request
        $hospital->name_en = $request->name_en;
        $hospital->name_bn = $request->input('name_bn');
        $hospital->name_ar = $request->input('name_ar');
        $hospital->name_hi = $request->input('name_hi');

        $hospital->content_en = $request->input('content_en');
        $hospital->content_ar = $request->input('content_ar');
        $hospital->content_hi = $request->input('content_hi');


        $hospital->is_top = $request->input('is_top');

        // Save the updated doctor record

        $hospital->save();
        // Update specialization mapping if specialization IDs are provided
        $sid = $request->input('specialization_id');
        $cityd = $request->input('city_id');

        if (isset($sid)) {
            $temp = [];
            foreach ($sid as $itemId) {
                array_push($temp, ["specialization_id" => $itemId, "hospital_id" => $hospital->id]);
            }
            // Delete existing mappings for the current doctor
            TreatmentMapping::where('hospital_id', $hospital->id)->delete();

            // Insert new mappings
            TreatmentMapping::insert($temp);
        }

        if (isset($cityd)) {
            $temp = [];
            foreach ($cityd as $itemId) {
                array_push($temp, ["city_id" => $itemId, "hospital_id" => $hospital->id]);
            }
            // Delete existing mappings for the current doctor
            CityMapping::where('hospital_id', $hospital->id)->delete();

            // Insert new mappings
            CityMapping::insert($temp);
        }

        return $hospital;
    }





    public function delete($id)
    {
        $hospital = Hospital::find($id);

        if (!$hospital) {
            return null; // or handle the case where doctor is not found
        }

        // Perform soft delete by updating the is_delete field
        $hospital->update(['is_delete' => 1]);

        return $hospital;
    }

}
