<?php

namespace App\Repositories;

use App\Models\Treatment;
use App\Repositories\Interfaces\Treatmentinterface;
use App\Traits\FileUploadTrait;
use Illuminate\Http\Request;
use Log;

class TreatmentRepository implements Treatmentinterface
{

    use FileUploadTrait;

    public function store(Request $request, $imgName, $imgNameIcon)
    {
        $treatment = new Treatment;
        $treatment->treatment_name_en = $request->input('treatment_name_en');
        $treatment->treatment_name_bn = $request->input('treatment_name_bn');
        $treatment->treatment_name_hi = $request->input('treatment_name_hi');
        $treatment->treatment_name_ar = $request->input('treatment_name_ar');

        $treatment->description_en = $request->input('description_en');
        $treatment->description_ar = $request->input('description_ar');
        $treatment->description_bn = $request->input('description_bn');
        $treatment->description_hi = $request->input('description_hi');

        $treatment->content_en = $request->input('content_en');
        $treatment->content_bn = $request->input('content_bn');
        $treatment->content_hi = $request->input('content_hi');
        $treatment->content_ar = $request->input('content_ar');

        $treatment->is_popular = $request->input('is_popular');
        $treatment->is_current = $request->input('is_current');

        // Set parent_id
        $treatment->parent_id = $request->input('parent_id');

        $treatment->img = $imgName;
        $treatment->icon = $imgNameIcon;

        $treatment->save();

        return $treatment;

    }

    public function list()
    {

        $list = Treatment::select('id', 'treatment_name_en', 'img', 'icon', 'is_delete')
            ->where('is_delete', 0)
            ->where('parent_id', 0)
            ->get();
        Log::info($list);

        $baseImgPath = $this->getBasePath();
        $list->map(function ($item) use ($baseImgPath) {
            if ($item->img != null) {
                $item['img'] = $baseImgPath . $item->img;
                $item['icon'] = $baseImgPath . $item->icon;
            } else {
                $item['img'] = null;
                $item['icon'] = null;
            }
        });

        return $list;

    }

    public function find($id)
    {
        $treatment = Treatment::find($id);
        $baseImgPath = $this->getBasePath();
        if ($treatment->img != null) {
            $treatment['img'] = $baseImgPath . $treatment->img;
            $treatment['icon'] = $baseImgPath . $treatment->icon;
        } else {
            $treatment['img'] = null;
            $treatment['icon'] = null;
        }
        Log::info($treatment);
        return $treatment;

    }

    public function update($id, Request $request, $imgName, $imgNameIcon)
    {
        $treatment = Treatment::find($request->id);
        // Check if the doctor record exists
        if (!$treatment) {
            return response()->json(['error' => 'Doctor not found'], 404);
        }

        $treatment->treatment_name_en = $request->input('treatment_name_en');
        $treatment->treatment_name_bn = $request->input('treatment_name_bn');
        $treatment->treatment_name_hi = $request->input('treatment_name_hi');
        $treatment->treatment_name_ar = $request->input('treatment_name_ar');

        $treatment->description_en = $request->input('description_en');
        $treatment->description_ar = $request->input('description_ar');
        $treatment->description_bn = $request->input('description_bn');
        $treatment->description_hi = $request->input('description_hi');

        $treatment->content_en = $request->input('content_en');
        $treatment->content_bn = $request->input('content_bn');
        $treatment->content_hi = $request->input('content_hi');
        $treatment->content_ar = $request->input('content_ar');

        $treatment->is_popular = $request->input('is_popular');
        $treatment->is_current = $request->input('is_current');

        $treatment->img = $imgName;
        $treatment->icon = $imgNameIcon;

        // Set parent_id
        $treatment->parent_id = $request->input('parent_id');

        $treatment->save();

        return $treatment;
    }

    public function getChildTreatments($parentId)
    {
        // Treatment::where('parent_id', $parentId)->get();
        $list = Treatment::select('id', 'treatment_name_en', 'img', 'icon', 'is_delete')
            ->where('parent_id', $parentId)
            ->where('is_delete', 0)
            ->get();
        Log::info($list);

        $baseImgPath = $this->getBasePath();
        $list->map(function ($item) use ($baseImgPath) {
            if ($item->img != null) {
                $item['img'] = $baseImgPath . $item->img;
                $item['icon'] = $baseImgPath . $item->icon;
            } else {
                $item['img'] = null;
                $item['icon'] = null;
            }
        });

        return $list;
    }

    public function delete($id)
    {
        $treatment = Treatment::find($id);

        if (!$treatment) {
            return null; // or handle the case where doctor is not found
        }

        // Perform soft delete by updating the is_delete field
        $treatment->update(['is_delete' => 1]);

        return $treatment;
    }
}
