<?php

namespace App\WebRepositories;

use App;
use App\Models\Doctor;
use App\Traits\FileUploadTrait;
use App\WebRepositories\Interfaces\DoctorInterface;
use DB;
use Illuminate\Http\Request;
use Log;

class DoctorRepository implements DoctorInterface
{

    use FileUploadTrait;

    public function getDoctor($id)
    {

        $locale = App::getLocale();

        $item = Doctor::select('id', "name_$locale as name"
            , "experience_$locale as experience", "description_$locale as description"
            , "qualification_$locale as qualification"
            , "about_doctor_$locale as about_doctor"
            , "work_exp_his_$locale as work_exp_his"
            ,"specialist_$locale as specialist"
            ,"awards_$locale as awards"
            , 'img', 'status_id', 'is_delete', 'is_top', 'hospital_id'
            , DB::raw("CONCAT('RBP', LPAD(id+741257, 10, '0')) AS ref")
            , 'fb_link', 'insta_link', 'twitter_link', 'linkdid')
            ->where('is_delete', 0)
            ->where('status_id', 1)
            ->where('id', $id)
            ->with(['hospitals' => function ($query) use ($locale) {
                $query->select('id', "name_$locale as name");
            }])->with(['spelizations.spelization' => function ($query) use ($locale) {
            $query->select('id', "treatment_name_$locale as name");
        }])->first();

        $baseImgPath = $this->getBasePath();

        if ($item == null) {
            return null;
        }
        if ($item->img != null) {

            $item['profilePicUrl'] = $baseImgPath . $item->img;

        } else {

            $item['profilePicUrl'] = null;

        }

        if ($item->hospitals != null) {
            $item['hospitalName'] = $item->hospitals->name;
        } else {
            $item['hospitalName'] = "NA";
        }

        unset($item->status_id, $item->img, $item->is_delete, $item->is_top, $item->hospitals);

        return $item;

    }

    public function getList(Request $request)
    {

        $locale = App::getLocale();

        $temp = Doctor::select('id', "name_$locale as name"
            , "experience_$locale as experience", "description_$locale as description"
            , 'img', 'status_id', 'is_delete', 'is_top', 'hospital_id'
            , DB::raw("CONCAT('RBP', LPAD(id+741257, 10, '0')) AS ref"))
            ->where('is_delete', 0)
            ->where('status_id', 1)
            ->orderBy('id', "DESC");

        $list = $temp->with(['hospitals' => function ($query) use ($locale) {
            $query->select('id', "name_$locale as name");
        }])->with(['spelizations.spelization' => function ($query) use ($locale) {
            $query->select('id', "treatment_name_$locale as name");
        }])->paginate(15);

        $baseImgPath = $this->getBasePath();

        $list->map(function ($item) use ($baseImgPath) {

            if ($item->img != null) {

                $item['profilePicUrl'] = $baseImgPath . $item->img;

            } else {

                $item['profilePicUrl'] = null;

            }

            if ($item->hospitals != null) {
                $item['hospitalName'] = $item->hospitals->name;
            } else {
                $item['hospitalName'] = "NA";
            }

            unset($item->status_id, $item->img, $item->is_delete, $item->is_top, $item->hospitals);
        });

        Log::info(json_encode($list));

        return $list;

    }
    public function getTopListByLimit($limit)
    {

        $locale = App::getLocale();

        $temp = Doctor::select('id', "name_$locale as name", "experience_$locale as experience"
         ,DB::raw("CONCAT('RBP', LPAD(id+741257, 10, '0')) AS ref")
            , 'img', 'status_id', 'is_delete', 'is_top')
            ->where('is_delete', 0)
            ->where('status_id', 1)
            ->where('is_top', 1)
            ->orderBy('id', "DESC");

        if ($limit != -1) {
            $temp = $temp->limit($limit);
        }
        $list = $temp->get();

        $baseImgPath = $this->getBasePath();

        $list->map(function ($item) use ($baseImgPath) {

            if ($item->img != null) {

                $item['profilePicUrl'] = $baseImgPath . $item->img;

            } else {

                $item['profilePicUrl'] = null;

            }

            unset($item->status_id, $item->img, $item->is_delete, $item->is_top);
        });

        Log::info(json_encode($list));

        return $list;

    }

}
