<?php

namespace App\WebRepositories;

use App;
use App\Models\CityMapping;
use App\Models\Hospital;
use App\Models\TreatmentMapping;
use App\Traits\CommonUtils;
use App\Traits\FileUploadTrait;
use App\WebRepositories\Interfaces\HospitalInterface;
use Illuminate\Http\Request;
use Log;

class HospitalRepository implements HospitalInterface
{

    use FileUploadTrait;
    use CommonUtils;

    public function getTopListByLimit($limit)
    {

        $locale = App::getLocale();

        $temp = Hospital::select('id', "name_$locale as name"
            , 'logo_img as logo', 'status_id', 'is_delete', 'is_top')
            ->where('is_delete', 0)
            ->where('status_id', 1)
            ->where('is_top', 1)
            ->orderBy('id', "DESC");

        if ($limit != -1) {
            $temp = $temp->with(['cityies.citys' => function ($query) use ($locale) {
                $query->select('id', "name_$locale as name");
            }])
                ->limit($limit);
        }
        $list = $temp->get();

        $baseImgPath = $this->getBasePath();

        $list->map(function ($item) use ($baseImgPath) {

            if ($item->logo != null) {

                $item['logoUrl'] = $baseImgPath . $item->logo;

            } else {

                $item['logoUrl'] = null;

            }
            $cityNames = array_map(function ($mItem) {
                return $mItem['citys']['name'];
            }, $item->cityies->toArray());

            $item['cityNames'] = implode(', ', $cityNames);
            unset($item->status_id, $item->logo, $item->is_delete, $item->status_id, $item->is_top, $item->cityies);
        });


       // Log::info(json_encode($list));

        return $list;

    }


    public function getHospitalById($hospitalId)
    {
        $locale = App::getLocale();
        $hospital = Hospital::select(
            'id',
            "name_$locale as name",
            "content_$locale as content",
            'logo_img',
            'img'
        )
            ->where('id', $hospitalId)
            ->first();
        if (!$hospital) {
            // Treatment not found
            return null;
        }
        $baseImgPath = $this->getBasePath();

        if ($hospital->img !== null) {
            $hospital['imgUrl'] = $baseImgPath . $hospital->img;
        } else {
            $hospital['imgUrl'] = null;
        }
        return $hospital;
    }

    public function getList(Request $request)
    {

        $locale = App::getLocale();

        $temp = Hospital::select('id', "name_$locale as name", "content_$locale as content"
            , 'logo_img as logo', 'img', 'status_id', 'is_delete', 'is_top')
            ->where('is_delete', 0)
            ->where('status_id', 1)
            ->orderBy('id', "DESC");

        $cityRef = $request->city_ref;

        if (isset($cityRef)) {

            $cityId = $this->getIdFromRefNumber($cityRef);

            $hospitalIds = CityMapping::where('city_id', $cityId)->pluck('hospital_id')->toArray();

            $temp = $temp->whereIn('id', $hospitalIds);
        }

        $treatmentRef = $request->treatment_ref;

        if (isset($treatmentRef)) {

            $treatmentId = $this->getIdFromRefNumber($treatmentRef);

            $hospitalIds = TreatmentMapping::where('specialization_id', $treatmentId)
                ->pluck('hospital_id')->toArray();

            $temp = $temp->whereIn('id', $hospitalIds);
        }

        $list = $temp->paginate(15);

        $baseImgPath = $this->getBasePath();

        $list->map(function ($item) use ($baseImgPath) {

            if ($item->img != null) {

                $item['imgUrl'] = $baseImgPath . $item->img;

            } else {

                $item['imgUrl'] = null;

            }

            unset($item->status_id, $item->logo, $item->img, $item->is_delete, $item->status_id, $item->is_top);
        });

        Log::info(json_encode($list));

        return $list;

    }
}
