<?php

namespace App\WebRepositories;

use App;
use App\Models\Treatment;
use App\Traits\FileUploadTrait;
use App\WebRepositories\Interfaces\Treatmentinterface;
use DB;
use Illuminate\Http\Request;

class TreatmentRepository implements Treatmentinterface
{

    use FileUploadTrait;

    public function getForPageInfo($id)
    {

        $locale = App::getLocale();

        $model = Treatment::select('id', "treatment_name_$locale as heading"
            , "description_$locale as content")->where('id', $id)
            ->first();

        return $model;
    }
    public function getTreatmentListByLimit($limit)
    {

        $locale = App::getLocale();

        $temp = Treatment::select('id', "treatment_name_$locale as name"
            , "description_$locale as description"
            , 'icon', 'status_id', 'is_delete', 'parent_id'
            , DB::raw("CONCAT('RBP', LPAD(id+741257, 10, '0')) AS ref"))
            ->where('is_delete', 0)
            ->where('status_id', 1)
            ->where('parent_id', 0)
            ->orderBy('id', "DESC");

        if ($limit != -1) {
            $temp = $temp->limit($limit);
        }
        $list = $temp->get();

        $baseImgPath = $this->getBasePath();

        $list->map(function ($item) use ($baseImgPath) {

            if ($item->icon != null) {

                $item['iconUrl'] = $baseImgPath . $item->icon;

            } else {

                $item['iconUrl'] = null;

            }

            unset($item->status_id, $item->icon, $item->is_delete, $item->parent_id);
        });

        return $list;

    }

    public function getTreatmentById($treatmentId)
    {
        $locale = App::getLocale();

        $treatment = Treatment::select(
            'id',
            "treatment_name_$locale as name",
            "description_$locale as description",
            "content_$locale as content",
            'icon',
            'status_id',
            'is_delete',
            'parent_id',
            'img'
        )
            ->where('id', $treatmentId)
            ->where('is_delete', 0)
            ->where('status_id', 1)
            ->first();

        if (!$treatment) {
            // Treatment not found
            return null;
        }

        $baseImgPath = $this->getBasePath();

        if ($treatment->img !== null) {
            $treatment['imgUrl'] = $baseImgPath . $treatment->img;
        } else {
            $treatment['imgUrl'] = null;
        }

        unset($treatment->status_id, $treatment->icon, $treatment->is_delete, $treatment->parent_id);

        return $treatment;
    }

    public function getTreatmentListByParentId(Request $request, $treatmentId)
    {

        $locale = App::getLocale();

        $temp = Treatment::select('id', "treatment_name_$locale as name"
            , "description_$locale as description"
            , 'img', 'status_id', 'is_delete', 'parent_id')
            ->where('is_delete', 0)
            ->where('status_id', 1)
            ->where('parent_id', $treatmentId)
            ->orderBy('id', "DESC");

        $list = $temp->paginate(15);

        $baseImgPath = $this->getBasePath();

        $list->map(function ($item) use ($baseImgPath) {

            if ($item->img != null) {

                $item['imgUrl'] = $baseImgPath . $item->img;

            } else {

                $item['imgUrl'] = null;

            }

            unset($item->status_id, $item->icon, $item->is_delete, $item->parent_id);
        });

        return $list;

    }

    public function getTreatmentCurrentOptios(Request $request)
    {

        $locale = App::getLocale();

        $temp = Treatment::select('id', "treatment_name_$locale as name"
            , 'img', 'status_id', 'is_delete')
            ->where('is_delete', 0)
            ->where('status_id', 1)
            ->where('is_current', 1)
            ->orderBy('id', "DESC");
        $list = $temp->limit(10)->get();

        $baseImgPath = $this->getBasePath();

        $list->map(function ($item) use ($baseImgPath) {

            if ($item->img != null) {

                $item['imgUrl'] = $baseImgPath . $item->img;

            } else {

                $item['imgUrl'] = null;

            }

            unset($item->status_id, $item->is_delete);
        });

        return $list;

    }

    public function getTreatmentpopular(Request $request)
    {

        $locale = App::getLocale();

        $temp = Treatment::select('id', "treatment_name_$locale as name"
            , 'img', 'status_id', 'is_delete')
            ->where('is_delete', 0)
            ->where('status_id', 1)
            ->where('is_popular', 1)
            ->orderBy('id', "DESC");
        $list = $temp->limit(10)->get();

        $baseImgPath = $this->getBasePath();

        $list->map(function ($item) use ($baseImgPath) {

            if ($item->img != null) {

                $item['imgUrl'] = $baseImgPath . $item->img;

            } else {

                $item['imgUrl'] = null;

            }

            unset($item->status_id, $item->is_delete);
        });

        return $list;

    }

}
