<?php

Route::group(['prefix' => '/super/admin', 'middleware' => 'system.staging'], function () {

    Route::group(['prefix' => '', 'middleware' => 'auth.user'], function () {
        Route::get('/files', ['as' => 'file.upload', 'uses' => 'FileController@uploadForm']);
        Route::post('/upload/file', ['as' => 'file.upload.submit', 'uses' => 'FileController@uploadFormSubmit']);

    });
    Route::group(['prefix' => '', 'namespace' => "Login"], function () {
        Route::get('/', ['as' => 'login', 'uses' => 'AuthController@index']);
        Route::post('/', ['as' => 'login.submit', 'uses' => 'AuthController@submitLogIn']);
        Route::get('/auth/deactive/logout/', ['as' => 'auth.deactive.logout', 'uses' => 'AuthController@logout']);
    });
    Route::group(['prefix' => '', 'namespace' => 'Login', 'middleware' => 'auth.user'], function () {
        Route::get('/auth/logout', ['as' => 'auth.logout', 'uses' => 'AuthController@logout']);
        Route::get('/dashboard', ['as' => 'dashboard', 'uses' => 'AuthController@dashboard']);
        Route::get('/form', ['as' => 'form', 'uses' => 'SampleController@form']);
        Route::get('/blank', ['as' => 'blank', 'uses' => 'SampleController@blank']);
        Route::get('/list', ['as' => 'list', 'uses' => 'SampleController@list']);

    });

    Route::group(['prefix' => '', 'namespace' => 'Admin', 'middleware' => 'auth.user'], function () {
        Route::get('/list', ['as' => 'sitesettings.list', 'uses' => 'SiteSettingsController@site_settings_admin']);
        Route::get('/site-settings/edit/{id}', ['as' => 'edit.site', 'uses' => 'SiteSettingsController@editSiteSettings']);
        Route::post('/site-settings/update/{id}', ['as' => 'update.site', 'uses' => 'SiteSettingsController@updateSiteSettings']);

    });

    Route::group(['prefix' => '/treatments', 'namespace' => 'Admin', 'middleware' => 'auth.user'], function () {
        Route::get('/', ['as' => 'treatment.list', 'uses' => 'TreatmentController@list']);
        Route::get('/new', ['as' => 'treatment.add', 'uses' => 'TreatmentController@create']);
        Route::post('/store', ['as' => 'treatment.store', 'uses' => 'TreatmentController@store']);
        Route::get('/edit/{id}', ['as' => 'treatment.edit', 'uses' => 'TreatmentController@edit']);
        Route::post('/update/{id}', ['as' => 'treatment.update', 'uses' => 'TreatmentController@update']);
        Route::get('/view/{id}', ['as' => 'treatment.view', 'uses' => 'TreatmentController@view']);
        Route::any('/delete/{id}', ['as' => 'treatment.delete', 'uses' => 'TreatmentController@delete']);
        // Add the new route for childrenTreatmentCreate
        Route::get('/{id}/create-child', ['as' => 'treatment.children.create', 'uses' => 'TreatmentController@childrenTreatmentCreate']);

        Route::post('/treatments/children/store/{id}', ['as' => 'treatment.children.store', 'uses' => 'TreatmentController@childrenTreatmentStore']);
        Route::get('/edit-child/{id}', ['as' => 'treatment.editChild', 'uses' => 'TreatmentController@childrenTreatmentEdit']);
        Route::post('/update-child/{id}', ['as' => 'treatment.updateChild', 'uses' => 'TreatmentController@childrenTreatmentUpdate']);


    });


    Route::group(['prefix' => '/doctors', 'namespace' => 'Admin', 'middleware' => 'auth.user'], function () {
        Route::get('/', ['as' => 'doctors.list', 'uses' => 'DoctorController@list']);
        Route::get('/create', ['as' => 'doctors.create', 'uses' => 'DoctorController@create']);
        Route::post('/store', ['as' => 'doctors.store', 'uses' => 'DoctorController@store']);
        Route::get('/edit/{id}', ['as' => 'doctors.edit', 'uses' => 'DoctorController@edit']);
        Route::post('/update/{id}', ['as' => 'doctors.update', 'uses' => 'DoctorController@update']);
        Route::any('/delete/{id}', ['as' => 'doctors.delete', 'uses' => 'DoctorController@delete']);
        Route::post('/update_img/{id}', ['as' => 'doctors.update_img', 'uses' => 'DoctorController@update_img']);



    });


    Route::group(['prefix' => '/countries', 'namespace' => 'Admin', 'middleware' => 'auth.user'], function () {
        Route::get('/', ['as' => 'countries.list', 'uses' => 'CountryController@list']);
        Route::get('/cities/{id}', ['as' => 'countries.city.list', 'uses' => 'CountryController@listCity']);
        Route::get('/new', ['as' => 'countries.add', 'uses' => 'CountryController@create']);
        Route::post('/store', ['as' => 'countries.store', 'uses' => 'CountryController@store']);
        Route::get('/edit/{id}', ['as' => 'countries.edit', 'uses' => 'CountryController@edit']);
        Route::post('/update/{id}', ['as' => 'countries.update', 'uses' => 'CountryController@update']);
        Route::get('/view/{id}', ['as' => 'countries.view', 'uses' => 'CountryController@view']);
        Route::any('/delete/{id}', ['as' => 'countries.delete', 'uses' => 'CountryController@delete']);
        Route::post('/store/city', ['as' => 'countries.store.city', 'uses' => 'CountryController@storeCity']);
        Route::post('/update/city/{id}', ['as' => 'countries.city.update', 'uses' => 'CountryController@updateCity']);
        Route::any('/delete/city/{id}', ['as' => 'countries.city.delete', 'uses' => 'CountryController@deleteCity']);


    });


    Route::group(['prefix' => '/course', 'namespace' => 'Admin', 'middleware' => 'auth.user'], function () {
        Route::get('/', ['as' => 'course.list', 'uses' => 'CourseController@list']);
        Route::get('/course/cat/list', ['as' => 'course.cat.list', 'uses' => 'CourseController@listCourseCat']);
        Route::post('/store/course/cat', ['as' => 'course.cat.store', 'uses' => 'CourseController@storeCat']);

        Route::get('/new', ['as' => 'course.add', 'uses' => 'CourseController@create']);
        Route::post('/store', ['as' => 'course.store', 'uses' => 'CourseController@store']);
        Route::get('/edit/{id}', ['as' => 'course.edit', 'uses' => 'CourseController@edit']);
        Route::post('/update/course/cat', ['as' => 'course.cat.update', 'uses' => 'CourseController@updateCat']);
        Route::post('/update/{id}', ['as' => 'course.update', 'uses' => 'CourseController@update']);
        Route::any('/delete/{id}', ['as' => 'course.delete', 'uses' => 'CourseController@delete']);
        Route::any('/delete/cat/{id}', ['as' => 'course.cat.delete', 'uses' => 'CourseController@deleteCat']);

    });

    Route::group(['prefix' => '/cms', 'namespace' => 'Admin', 'middleware' => 'auth.user'], function () {
        Route::get('/', ['as' => 'cms.list', 'uses' => 'CmsController@list']);
        Route::get('/create', ['as' => 'cms.create', 'uses' => 'CmsController@create']);
        Route::post('/store', ['as' => 'cms.store', 'uses' => 'CmsController@store']);
        Route::get('/edit/{id}', ['as' => 'cms.edit', 'uses' => 'CmsController@edit']);
        Route::post('/update/{id}', ['as' => 'cms.update', 'uses' => 'CmsController@update']);
        Route::any('/delete/{id}', ['as' => 'cms.delete', 'uses' => 'CmsController@delete']);


    });


    Route::group(['prefix' => '/city', 'namespace' => 'Admin', 'middleware' => 'auth.user'], function () {
        Route::get('/', ['as' => 'city.list', 'uses' => 'CityController@list']);
        Route::get('/create', ['as' => 'city.create', 'uses' => 'CityController@create']);
        Route::post('/store', ['as' => 'city.store', 'uses' => 'CityController@store']);
        Route::get('/edit/{id}', ['as' => 'city.edit', 'uses' => 'CityController@edit']);
        Route::post('/update/{id}', ['as' => 'city.update', 'uses' => 'CityController@update']);
        Route::any('/delete/{id}', ['as' => 'city.delete', 'uses' => 'CityController@delete']);


    });

    Route::group(['prefix' => '/hospital', 'namespace' => 'Admin', 'middleware' => 'auth.user'], function () {
        Route::get('/', ['as' => 'hospital.list', 'uses' => 'HospitalController@list']);
        Route::get('/create', ['as' => 'hospital.create', 'uses' => 'HospitalController@create']);
        Route::post('/store', ['as' => 'hospital.store', 'uses' => 'HospitalController@store']);
        Route::get('/edit/{id}', ['as' => 'hospital.edit', 'uses' => 'HospitalController@edit']);
        Route::post('/update/{id}', ['as' => 'hospital.update', 'uses' => 'HospitalController@update']);
        Route::any('/delete/{id}', ['as' => 'hospital.delete', 'uses' => 'HospitalController@delete']);
        Route::post('/update_img/{id}', ['as' => 'hospital.update_img', 'uses' => 'HospitalController@update_img']);
        Route::post('/update_logo/{id}', ['as' => 'hospital.update_logo', 'uses' => 'HospitalController@update_logo']);



    });


    Route::group(['prefix' => '/enquery', 'namespace' => 'Admin', 'middleware' => 'auth.user'], function () {
        Route::get('/', ['as' => 'enquery.list', 'uses' => 'EnqueryController@list']);
        Route::get('/create', ['as' => 'enquery.create', 'uses' => 'EnqueryController@create']);
        Route::post('/store', ['as' => 'enquery.store', 'uses' => 'EnqueryController@store']);
        Route::get('/edit/{id}', ['as' => 'enquery.edit', 'uses' => 'EnqueryController@edit']);
        Route::post('/update/{id}', ['as' => 'enquery.update', 'uses' => 'EnqueryController@update']);
        Route::any('/delete/{id}', ['as' => 'enquery.delete', 'uses' => 'EnqueryController@delete']);
        Route::post('/update_img/{id}', ['as' => 'enquery.update_img', 'uses' => 'EnqueryController@update_img']);



    });

    Route::group(['prefix' => '/newsletter', 'namespace' => 'Admin', 'middleware' => 'auth.user'], function () {
        Route::get('/', ['as' => 'newsletter.list', 'uses' => 'NewsLetterController@list']);

    });


    Route::group(['prefix' => '/testimonials', 'namespace' => 'Admin', 'middleware' => 'auth.user'], function () {
        Route::get('/', ['as' => 'testimonials.list', 'uses' => 'TestimonialsController@list']);
        Route::get('/create', ['as' => 'testimonials.create', 'uses' => 'TestimonialsController@create']);
        Route::post('/store', ['as' => 'testimonials.store', 'uses' => 'TestimonialsController@store']);
        Route::get('/edit/{id}', ['as' => 'testimonials.edit', 'uses' => 'TestimonialsController@edit']);
        Route::post('/update/{id}', ['as' => 'testimonials.update', 'uses' => 'TestimonialsController@update']);
        Route::any('/delete/{id}', ['as' => 'testimonials.delete', 'uses' => 'TestimonialsController@delete']);
        Route::post('/update_img/{id}', ['as' => 'testimonials.update_img', 'uses' => 'TestimonialsController@update_img']);
        Route::post('/update_logo/{id}', ['as' => 'testimonials.update_logo', 'uses' => 'TestimonialsController@update_logo']);



    });
    Route::group(['prefix' => '/teams', 'namespace' => 'Admin', 'middleware' => 'auth.user'], function () {
        Route::get('/', ['as' => 'teams.list', 'uses' => 'TeamController@list']);
        Route::get('/create', ['as' => 'teams.create', 'uses' => 'TeamController@create']);
        Route::post('/store', ['as' => 'teams.store', 'uses' => 'TeamController@store']);
        Route::get('/edit/{id}', ['as' => 'teams.edit', 'uses' => 'TeamController@edit']);
        Route::post('/update/{id}', ['as' => 'teams.update', 'uses' => 'TeamController@update']);
        Route::any('/delete/{id}', ['as' => 'teams.delete', 'uses' => 'TeamController@delete']);
        Route::post('/update_img/{id}', ['as' => 'teams.update_img', 'uses' => 'TeamController@update_img']);
        Route::post('/update_logo/{id}', ['as' => 'teams.update_logo', 'uses' => 'TeamController@update_logo']);



    });

});
